#!/bin/sh

#
# configure and compile libtool for scratchbox target
#
# target name is to passed as argument
#

source /targets/links/scratchbox.config

if test "$1" = "" ; then
	exit 1;
fi
TARGET_NAME=$1

LIBTOOL=libtool-1.5.2
WORKDIR=`mktemp -d -p $HOME`

LIBTOOL_PKG=/scratchbox/packages/${LIBTOOL}.tar.gz
LIBTOOL_SRC_DIR=${WORKDIR}/${LIBTOOL}

INSTALL_PREFIX=/host_usr/libtool/$TARGET_NAME

cd $WORKDIR
if [ ! -f $LIBTOOL_PKG ] ; then
	echo "could not find libtool package: $LIBTOOL_PKG"
	exit 1
fi
tar -xzf $LIBTOOL_PKG

rm -rf $INSTALL_PREFIX 2>/dev/null

cd $LIBTOOL_SRC_DIR

echo "configuring libtool for $TARGET_NAME target"
echo "this may take a while..."

cat <<EOF > config.cache
lt_cv_dlopen_self=\${lt_cv_dlopen_self='yes'}
lt_cv_dlopen_self_static=\${lt_cv_dlopen_self_static='yes'}
EOF

ok=true

./configure --prefix=$INSTALL_PREFIX  --host=`./config.guess` --target=${SBOX_CPU}-${SBOX_OS} -C NM="/scratchbox/compilers/bin/nm -B" > /dev/null 2>&1
if test $? -ne 0 ; then error=true ; fi

$ok && make > /dev/null 2>&1
if test $? -ne 0 ; then ok=false ; fi

$ok && make install > /dev/null 2>&1
if test $? -ne 0 ; then ok=false ; fi

rm -rf $WORKDIR

if $ok ; then
echo "libtool is installed to $INSTALL_PREFIX/bin/libtool"
else
echo "There were some errors. libtool is NOT correctly installed"
fi
